import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

extension Hex on Color {
  /// return hex String
  String toHex({bool leadingHashSign = true, bool includeAlpha = false}) =>
      '${leadingHashSign ? '#' : ''}'
      '${includeAlpha ? alpha.toRadixString(16).padLeft(2, '0') : ''}'
      '${red.toRadixString(16).padLeft(2, '0')}'
      '${green.toRadixString(16).padLeft(2, '0')}'
      '${blue.toRadixString(16).padLeft(2, '0')}';
}

extension IntExtensions on int {
  /// Validate given int is not null and returns given value if null.
  int validate({int value = 0}) => this ?? value;

  /// Leaves given height of space
  Widget get height => SizedBox(height: this.toDouble());

  /// Leaves given width of space
  Widget get width => SizedBox(width: this.toDouble());

  /// HTTP status code
  bool isSuccessful() {
    return this >= 200 && this <= 206;
  }
}

extension DoubleExtensions on double {
  /// Validate given double is not null and returns given value if null.
  double validate({double value = 0.0}) => this ?? value;
}

extension BooleanExtensions on bool {
  /// Validate given bool is not null and returns given value if null.
  bool validate({bool value = false}) => this ?? value;
}

extension ListExtensions<T> on Iterable<T> {
  /// Validate given List is not null and returns blank list if null.
  List<T> validate() {
    return this ?? List<T>();
  }

  /// Generate forEach but gives index for each element
  void forEachIndexed(void action(T element, int index)) {
    var index = 0;
    for (var element in this) {
      action(element, index++);
    }
  }
}

extension ObjectExtensions<T> on Object {
  /// Print object
  void log() {
    if (!kReleaseMode) print(this);
  }
}
