import 'package:flutter/material.dart';
import 'package:nb_utils/src/widgets/loader.dart';

import '../nb_utils.dart';

/// show confirm dialog box
Future<bool> showConfirmDialog<bool>(
  context,
  String title, {
  String positiveText = 'Yes',
  String negativeText = 'No',
  Color buttonColor,
  bool barrierDismissible,
}) async {
  return showDialog(
    context: context,
    barrierDismissible: barrierDismissible ?? false,
    child: AlertDialog(
      title: Text(title.validate(), style: primaryTextStyle()),
      actions: <Widget>[
        SimpleDialogOption(
          child: Text(negativeText.validate(), style: secondaryTextStyle()),
          onPressed: () {
            finish(context, false);
          },
        ),
        SimpleDialogOption(
          onPressed: () {
            finish(context, true);
          },
          child: Text(positiveText.validate(),
              style: primaryTextStyle(
                  color: buttonColor ?? Theme.of(context).primaryColor)),
        ),
      ],
    ),
  );
}

/// show child widget in dialog
Future<dynamic> showInDialog(
  BuildContext context, {
  Widget title,
  Widget child,
  ShapeBorder shape,
  TextStyle titleTextStyle,
  EdgeInsetsGeometry contentPadding =
      const EdgeInsets.fromLTRB(24.0, 20.0, 24.0, 24.0),
  //bool scrollable = false,
  Color backgroundColor,
  double elevation,
  //EdgeInsets insetPadding = const EdgeInsets.symmetric(horizontal: 16.0, vertical: 16.0),
  List<Widget> actions,
  bool barrierDismissible = true,
}) async {
  return await showDialog(
    context: context,
    barrierDismissible: barrierDismissible,
    child: AlertDialog(
      content: child,
      shape: shape,
      title: title,
      titleTextStyle: titleTextStyle,
      contentPadding: contentPadding,
      //scrollable: scrollable,
      backgroundColor: backgroundColor,
      elevation: elevation,
      //insetPadding: insetPadding,
      actions: actions,
    ),
  );
}

/// Default AppBar
AppBar appBarWidget(
  String title, {
  List<Widget> actions,
  Color color,
  bool center = false,
  Color textColor,
  int textSize = 20,
  bool showBack = true,
  Color shadowColor,
  double elevation,
}) {
  return AppBar(
    centerTitle: center,
    title: Text(title,
        style: boldTextStyle(
            color: textColor ?? textPrimaryColorGlobal, size: textSize)),
    actions: actions,
    automaticallyImplyLeading: showBack,
    backgroundColor: color ?? appBarBackgroundColorGlobal,
    leading: showBack
        ? BackButton(color: textColor ?? textPrimaryColorGlobal)
        : null,
    shadowColor: shadowColor,
    elevation: elevation ?? defaultAppBarElevation,
  );
}

/// Handle error and loading widget when using FutureBuilder or StreamBuilder
Widget snapWidgetHelper<T>(
  AsyncSnapshot<T> snap, {
  Widget errorWidget,
  Widget loadingWidget,
  String defaultErrorMessage,
  bool checkHasData = false,
}) {
  if (snap.hasError) {
    log(snap.error);
    return errorWidget ??
        Text(
          defaultErrorMessage ?? snap.error.toString(),
          style: primaryTextStyle(),
        ).center();
  } else {
    if (checkHasData && isSnapshotLoading(snap, checkHasData: checkHasData)) {
      return loadingWidget ?? Loader();
    }
    return loadingWidget ?? Loader();
  }
}

/// Returns true is snapshot is loading
bool isSnapshotLoading(AsyncSnapshot snap, {bool checkHasData = false}) {
  if (checkHasData) {
    return !snap.hasData &&
        !snap.hasError &&
        snap.connectionState != ConnectionState.done;
  } else {
    return snap.connectionState != ConnectionState.done;
  }
}
